==> stack-2.9.3.1-102-loong64.pkg.tar.zst: usr/share/haskell/register/stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-65aU8Bg5qwx2vQqxndJV5M
key:                  stack-2.9.3.1-65aU8Bg5qwx2vQqxndJV5M
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  bb6c958c15f6d34e71fecccc0677f262
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-65aU8Bg5qwx2vQqxndJV5M
depends:
    Cabal-3.10.3.0 aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh array-0.5.6.0
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 casa-client-0.0.3-IMwiZeo8KyaD5bz8GZCtq4
    casa-types-0.0.3-9s1eRoPqUMAI0rFVV9RayN
    colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6 containers-0.6.7
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    crypton-conduit-0.2.3-3EN5zse1H5T29qz3O5MqJq deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-IkudFHstV64EKMSGT8IWWb
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-Jbu16lZu6N3NkhqJBNYLr filepath-1.4.300.1
    fsnotify-0.4.4.0-IPbL2aIEyJBDpStmRnbeT6
    generic-deriving-1.14.6-EuFohhXhdng2D0y7uvFJO5
    hackage-security-0.6.3.2-6h6sjFOxYt52kQVswo2JRl
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hi-file-parser-0.1.8.0-8qisbnW7BoWAxztuEmkbHw
    hpack-0.38.0-KzucHDb4C1kBfakJLfPcEB hpc-0.6.2.0
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
    http-download-0.2.1.0-AKq2NKBxRMyCC593Obud3e
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-DRPwtEa2I1e57PO0WNa046 mtl-2.3.1
    mustache-2.4.3.1-fK5yHeZZtM7dOSrI5Pxnb
    neat-interpolation-0.5.1.4-4VDX25yQx4CGEE32HBtT8D
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    pantry-0.8.2.2-4rQRUbQjdBOIVN4BNWdWaL
    path-0.9.6-JZJSfxZgLNX9Y539GdP67P
    path-io-1.8.2-CWPMy5Meh3QEKkmaY17vKO
    persistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k
    persistent-sqlite-2.13.1.1-E48tqF9oldf4Mp9WevHUeT pretty-1.1.3.6
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi process-1.6.19.0
    project-template-0.2.1.0-9hbVFYsOwWq6cA49U23QYs
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    retry-0.9.3.1-FYTMxXzp6ILABIm5Dm7RjL
    rio-0.1.22.0-9YWPFaDDA8QAvZjRU1ibSo
    rio-prettyprint-0.1.8.0-1E5SvMAHYizIzsYMRS3OM
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    streaming-commons-0.2.3.1-J8SxFARI4BPDYt3Np6OVv5
    tar-0.5.1.1-4iAxOGYV1lQH2RPEJbrO6a template-haskell-2.20.0.0
    temporary-1.3-29RL4tTXoFB72QSCtJnhBC text-2.0.2
    text-metrics-0.3.3-542FvMYuyImLLT35eUtKmy
    th-reify-many-0.1.10-3aSXEZO0WLV6vSakOufT0x time-1.12.2
    tls-2.0.6-CMnie4Wyps5DmePV9nSMbU transformers-0.6.1.0
    typed-process-0.2.13.0-6gQ7sh9yVXJ5lWoFriePEE
    unicode-transforms-0.4.0.1-8iUmpGDdbp7ICIQfCprjLO unix-2.8.4.0
    unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    yaml-0.11.11.2-HJgRwey6BMIIq0hOFQKRBa
    zip-archive-0.4.3.2-ICmkrWQlOHqIMrYTQRjWIn
    zlib-0.7.0.0-H0rgJT2cf7y1jpEf30oLpw

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stack-2.9.3.1-103-loong64.pkg.tar.zst: usr/share/haskell/register/stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-1uYB1sB75pZKjUGBLHPwl1
key:                  stack-2.9.3.1-1uYB1sB75pZKjUGBLHPwl1
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  969c55dc53199bc8106c93e099c69a7b
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-1uYB1sB75pZKjUGBLHPwl1
depends:
    Cabal-3.10.3.0 aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh array-0.5.6.0
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 casa-client-0.0.3-IMwiZeo8KyaD5bz8GZCtq4
    casa-types-0.0.3-9s1eRoPqUMAI0rFVV9RayN
    colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6 containers-0.6.7
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    crypton-conduit-0.2.3-3EN5zse1H5T29qz3O5MqJq deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-IkudFHstV64EKMSGT8IWWb
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-Jbu16lZu6N3NkhqJBNYLr filepath-1.4.300.1
    fsnotify-0.4.4.0-IPbL2aIEyJBDpStmRnbeT6
    generic-deriving-1.14.6-EuFohhXhdng2D0y7uvFJO5
    hackage-security-0.6.3.2-6h6sjFOxYt52kQVswo2JRl
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hi-file-parser-0.1.8.0-IKXf9pTnjiJ1G8wAKWQiA2
    hpack-0.38.0-KzucHDb4C1kBfakJLfPcEB hpc-0.6.2.0
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
    http-download-0.2.1.0-AoDsIFjegNeY1k652XrTH
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-DRPwtEa2I1e57PO0WNa046 mtl-2.3.1
    mustache-2.4.3.1-fK5yHeZZtM7dOSrI5Pxnb
    neat-interpolation-0.5.1.4-4VDX25yQx4CGEE32HBtT8D
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    pantry-0.8.2.2-3of99dq3wp69lKfMHQbZMg
    path-0.9.6-JZJSfxZgLNX9Y539GdP67P
    path-io-1.8.2-CWPMy5Meh3QEKkmaY17vKO
    persistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k
    persistent-sqlite-2.13.1.1-E48tqF9oldf4Mp9WevHUeT pretty-1.1.3.6
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi process-1.6.19.0
    project-template-0.2.1.0-9hbVFYsOwWq6cA49U23QYs
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    retry-0.9.3.1-FYTMxXzp6ILABIm5Dm7RjL
    rio-0.1.24.0-FBO4PrA6UlqFqVtMb3OxSz
    rio-prettyprint-0.1.8.0-4VEed9eIFha1YPzhahlWIJ
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    streaming-commons-0.2.3.1-J8SxFARI4BPDYt3Np6OVv5
    tar-0.5.1.1-4iAxOGYV1lQH2RPEJbrO6a template-haskell-2.20.0.0
    temporary-1.3-29RL4tTXoFB72QSCtJnhBC text-2.0.2
    text-metrics-0.3.3-542FvMYuyImLLT35eUtKmy
    th-reify-many-0.1.10-3aSXEZO0WLV6vSakOufT0x time-1.12.2
    tls-2.0.6-CMnie4Wyps5DmePV9nSMbU transformers-0.6.1.0
    typed-process-0.2.13.0-6gQ7sh9yVXJ5lWoFriePEE
    unicode-transforms-0.4.0.1-8iUmpGDdbp7ICIQfCprjLO unix-2.8.4.0
    unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    yaml-0.11.11.2-HJgRwey6BMIIq0hOFQKRBa
    zip-archive-0.4.3.2-ICmkrWQlOHqIMrYTQRjWIn
    zlib-0.7.0.0-H0rgJT2cf7y1jpEf30oLpw

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
